Two methods are implemented to cluster data with finite mixture
regression models. Those procedures deal with high-dimensional covariates and
responses through a variable selection procedure based on the Lasso estimator.
The main function is runValse(), which calls all other functions.
See also plot_valse() which plots the relevant parameters after a run.